@@ -1,12 +1,14 @@
 package Sah::Schema::date::dow_name::id;
 
+use strict;
+
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-08-04'; # DATE
+our $DATE = '2022-10-20'; # DATE
 our $DIST = 'Sah-Schemas-Date-ID'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 our $schema = [cistr => {
-    summary => 'Day-of-week name (abbreviated or full, in Indonesian)',
+    summary => 'Day-of-week name (abbreviated or full, in Indonesian), e.g. "min" or "Sabtu"',
     in => [
         qw/mg sn sl rb km jm sb/,
         qw/min sen sel rab kam jum sab/,
@@ -31,7 +33,7 @@ _
 
 1;
 
-# ABSTRACT: Day-of-week name (abbreviated or full, in Indonesian)
+# ABSTRACT: Day-of-week name (abbreviated or full, in Indonesian), e.g. "min" or "Sabtu"
 
 __END__
 
@@ -41,17 +43,17 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::date::dow_name::id - Day-of-week name (abbreviated or full, in Indonesian)
+Sah::Schema::date::dow_name::id - Day-of-week name (abbreviated or full, in Indonesian), e.g. "min" or "Sabtu"
 
 =head1 VERSION
 
-This document describes version 0.007 of Sah::Schema::date::dow_name::id (from Perl distribution Sah-Schemas-Date-ID), released on 2021-08-04.
+This document describes version 0.008 of Sah::Schema::date::dow_name::id (from Perl distribution Sah-Schemas-Date-ID), released on 2022-10-20.
 
 =head1 SYNOPSIS
 
 =head2 Sample data and validation results against this schema
 
- ""  # INVALID (Empty string)
+ ""  # INVALID
 
  "mg"  # valid
 
@@ -61,7 +63,7 @@ This document describes version 0.007 of Sah::Schema::date::dow_name::id (from P
 
  "sun"  # INVALID (English)
 
- 1  # INVALID (Not a name)
+ 1  # INVALID
 
 =head2 Using with Data::Sah
 
@@ -71,7 +73,7 @@ To check data against this schema (requires L<Data::Sah>):
  my $validator = gen_validator("date::dow_name::id*");
  say $validator->($data) ? "valid" : "INVALID!";
 
-The above schema returns a boolean value (true if data is valid, false if
+The above schema returns a boolean result (true if data is valid, false if
 otherwise). To return an error message string instead (empty string if data is
 valid, a non-empty error message otherwise):
 
@@ -79,11 +81,11 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "min";
+ $data = "mg";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = "sun";
+ $data = "";
  my $errmsg = $validator->($data); # => "Must be one of [\"mg\",\"sn\",\"sl\",\"rb\",\"km\",\"jm\",\"sb\",\"min\",\"sen\",\"sel\",\"rab\",\"kam\",\"jum\",\"sab\",\"minggu\",\"senin\",\"selasa\",\"rabu\",\"kamis\",\"jumat\",\"sabtu\"]"
 
 Often a schema has coercion rule or default value, so after validation the
@@ -94,14 +96,14 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "min";
- my $res = $validator->($data); # => ["","min"]
+ $data = "mg";
+ my $res = $validator->($data); # => ["","mg"]
  
  # a sample invalid data
- $data = "sun";
- my $res = $validator->($data); # => ["Must be one of [\"mg\",\"sn\",\"sl\",\"rb\",\"km\",\"jm\",\"sb\",\"min\",\"sen\",\"sel\",\"rab\",\"kam\",\"jum\",\"sab\",\"minggu\",\"senin\",\"selasa\",\"rabu\",\"kamis\",\"jumat\",\"sabtu\"]","sun"]
+ $data = "";
+ my $res = $validator->($data); # => ["Must be one of [\"mg\",\"sn\",\"sl\",\"rb\",\"km\",\"jm\",\"sb\",\"min\",\"sen\",\"sel\",\"rab\",\"kam\",\"jum\",\"sab\",\"minggu\",\"senin\",\"selasa\",\"rabu\",\"kamis\",\"jumat\",\"sabtu\"]",""]
 
-Data::Sah can also create validator that returns a hash of detaild error
+Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
 JavaScript, from the same schema. Other things Data::Sah can do: show source
 code for validator, generate a validator code with debug comments and/or log
@@ -162,11 +164,22 @@ L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
-=head1 DESCRIPTION
 
-See also related schemas for other locales, e.g.
-L<Sah::Schema::date::dow_name::en> (English),
-L<Sah::Schema::date::dow_name::en_or_id> (English/Indonesian), etc.
+=head2 Using with Type::Tiny
+
+To create a type constraint and type library from a schema:
+
+ package My::Types {
+     use Type::Library -base;
+     use Type::FromSah qw( sah2type );
+
+     __PACKAGE__->add_type(
+         sah2type('$sch_name*', name=>'DateDowNameId')
+     );
+ }
+
+ use My::Types qw(DateDowNameId);
+ DateDowNameId->assert_valid($data);
 
 =head1 HOMEPAGE
 
@@ -176,6 +189,35 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Date-ID>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2020, 2019 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Date-ID>
@@ -184,15 +226,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020, 2019 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
