@@ -1,12 +1,14 @@
 package Sah::Schema::date::dow_num::en_or_id;
 
+use strict;
+
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-08-04'; # DATE
+our $DATE = '2022-10-20'; # DATE
 our $DIST = 'Sah-Schemas-Date-ID'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 our $schema = [int => {
-    summary => 'Day-of-week number (1-7, 1=Monday, like DateTime), coercible from English/Indonesian day-of-week name (Mo/Sn/MON/SEN/monday/senin)',
+    summary => 'Day-of-week number (1-7, 1=Monday, like DateTime), coercible from English/Indonesian day-of-week name (Mo/Sn/MON/SEN/monday/senin), e.g. 1 or "Sen" or "Mon"',
     min => 1,
     max => 7,
     'x.perl.coerce_rules' => ['From_str::convert_en_or_id_dow_name_to_num'],
@@ -31,7 +33,7 @@ _
 
 1;
 
-# ABSTRACT: Day-of-week number (1-7, 1=Monday, like DateTime), coercible from English/Indonesian day-of-week name (Mo/Sn/MON/SEN/monday/senin)
+# ABSTRACT: Day-of-week number (1-7, 1=Monday, like DateTime), coercible from English/Indonesian day-of-week name (Mo/Sn/MON/SEN/monday/senin), e.g. 1 or "Sen" or "Mon"
 
 __END__
 
@@ -41,29 +43,25 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::date::dow_num::en_or_id - Day-of-week number (1-7, 1=Monday, like DateTime), coercible from English/Indonesian day-of-week name (Mo/Sn/MON/SEN/monday/senin)
+Sah::Schema::date::dow_num::en_or_id - Day-of-week number (1-7, 1=Monday, like DateTime), coercible from English/Indonesian day-of-week name (Mo/Sn/MON/SEN/monday/senin), e.g. 1 or "Sen" or "Mon"
 
 =head1 VERSION
 
-This document describes version 0.007 of Sah::Schema::date::dow_num::en_or_id (from Perl distribution Sah-Schemas-Date-ID), released on 2021-08-04.
+This document describes version 0.008 of Sah::Schema::date::dow_num::en_or_id (from Perl distribution Sah-Schemas-Date-ID), released on 2022-10-20.
 
 =head1 SYNOPSIS
 
 =head2 Sample data and validation results against this schema
 
- ""  # INVALID (Not in 1-7)
+ ""  # INVALID
 
  0  # INVALID
 
  1  # valid
 
- "Tue"  # valid, becomes 2
-
- "SEL"  # valid, becomes 2
-
  7  # valid
 
- 8  # INVALID (Not in 1-7)
+ 8  # INVALID
 
 =head2 Using with Data::Sah
 
@@ -73,7 +71,7 @@ To check data against this schema (requires L<Data::Sah>):
  my $validator = gen_validator("date::dow_num::en_or_id*");
  say $validator->($data) ? "valid" : "INVALID!";
 
-The above schema returns a boolean value (true if data is valid, false if
+The above schema returns a boolean result (true if data is valid, false if
 otherwise). To return an error message string instead (empty string if data is
 valid, a non-empty error message otherwise):
 
@@ -81,7 +79,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "SEL";
+ $data = 1;
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
@@ -96,14 +94,14 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "SEL";
- my $res = $validator->($data); # => ["",2]
+ $data = 1;
+ my $res = $validator->($data); # => ["",1]
  
  # a sample invalid data
  $data = "";
  my $res = $validator->($data); # => ["Not of type integer",""]
 
-Data::Sah can also create validator that returns a hash of detaild error
+Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
 JavaScript, from the same schema. Other things Data::Sah can do: show source
 code for validator, generate a validator code with debug comments and/or log
@@ -164,6 +162,23 @@ L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
+
+=head2 Using with Type::Tiny
+
+To create a type constraint and type library from a schema:
+
+ package My::Types {
+     use Type::Library -base;
+     use Type::FromSah qw( sah2type );
+
+     __PACKAGE__->add_type(
+         sah2type('$sch_name*', name=>'DateDowNumEnOrId')
+     );
+ }
+
+ use My::Types qw(DateDowNumEnOrId);
+ DateDowNumEnOrId->assert_valid($data);
+
 =head1 DESCRIPTION
 
 Like the L<date::dow_num|Sah::Schema::date::dow_num> schema, except with
@@ -177,14 +192,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Date-ID>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Date-ID>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Sah::Schema::date::dow_num>
@@ -195,11 +202,37 @@ L<Sah::Schema::date::dow_num::id>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2020, 2019 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Date-ID>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
