@@ -1,12 +1,14 @@
 package Sah::Schema::date::dow_nums::en_or_id;
 
+use strict;
+
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-08-04'; # DATE
+our $DATE = '2022-10-20'; # DATE
 our $DIST = 'Sah-Schemas-Date-ID'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 our $schema = ['array' => {
-    summary => 'Array of day-of-week numbers (1-7, 1=Monday)',
+    summary => 'Array of day-of-week numbers (1-7, 1=Monday), e.g. [1,"Mon","Sen"]',
     of => ['date::dow_num::en_or_id', {}],
     'x.perl.coerce_rules' => ['From_str::comma_sep'],
     'x.completion' => ['date_dow_nums_en_or_id'],
@@ -34,7 +36,7 @@ _
 
 1;
 
-# ABSTRACT: Array of day-of-week numbers (1-7, 1=Monday)
+# ABSTRACT: Array of day-of-week numbers (1-7, 1=Monday), e.g. [1,"Mon","Sen"]
 
 __END__
 
@@ -44,11 +46,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::date::dow_nums::en_or_id - Array of day-of-week numbers (1-7, 1=Monday)
+Sah::Schema::date::dow_nums::en_or_id - Array of day-of-week numbers (1-7, 1=Monday), e.g. [1,"Mon","Sen"]
 
 =head1 VERSION
 
-This document describes version 0.007 of Sah::Schema::date::dow_nums::en_or_id (from Perl distribution Sah-Schemas-Date-ID), released on 2021-08-04.
+This document describes version 0.008 of Sah::Schema::date::dow_nums::en_or_id (from Perl distribution Sah-Schemas-Date-ID), released on 2022-10-20.
 
 =head1 SYNOPSIS
 
@@ -56,7 +58,7 @@ This document describes version 0.007 of Sah::Schema::date::dow_nums::en_or_id (
 
  ""  # valid, becomes []
 
- 0  # INVALID (Has number not in 1-7)
+ 0  # INVALID
 
  1  # valid, becomes [1]
 
@@ -64,13 +66,9 @@ This document describes version 0.007 of Sah::Schema::date::dow_nums::en_or_id (
 
  [1,7]  # valid
 
- ["Mon","MINGGu"]  # valid, becomes [1,7]
+ "1,7,8"  # INVALID
 
- "Mo,mg"  # valid, becomes [1,7]
-
- "1,7,8"  # INVALID (Has number not in 1-7)
-
- [1,7,8]  # INVALID (Has number not in 1-7)
+ [1,7,8]  # INVALID
 
 =head2 Using with Data::Sah
 
@@ -80,7 +78,7 @@ To check data against this schema (requires L<Data::Sah>):
  my $validator = gen_validator("date::dow_nums::en_or_id*");
  say $validator->($data) ? "valid" : "INVALID!";
 
-The above schema returns a boolean value (true if data is valid, false if
+The above schema returns a boolean result (true if data is valid, false if
 otherwise). To return an error message string instead (empty string if data is
 valid, a non-empty error message otherwise):
 
@@ -88,12 +86,12 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "";
+ $data = 1;
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = [1,7,8];
- my $errmsg = $validator->($data); # => "\@[2]: Must be at most 7"
+ $data = 0;
+ my $errmsg = $validator->($data); # => "\@[0]: Must be at least 1"
 
 Often a schema has coercion rule or default value, so after validation the
 validated value is different. To return the validated (set-as-default, coerced,
@@ -103,14 +101,14 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "";
- my $res = $validator->($data); # => ["",[]]
+ $data = 1;
+ my $res = $validator->($data); # => ["",[1]]
  
  # a sample invalid data
- $data = [1,7,8];
- my $res = $validator->($data); # => ["\@[2]: Must be at most 7",[1,7,8]]
+ $data = 0;
+ my $res = $validator->($data); # => ["\@[0]: Must be at least 1",[0]]
 
-Data::Sah can also create validator that returns a hash of detaild error
+Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
 JavaScript, from the same schema. Other things Data::Sah can do: show source
 code for validator, generate a validator code with debug comments and/or log
@@ -171,6 +169,23 @@ L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
+
+=head2 Using with Type::Tiny
+
+To create a type constraint and type library from a schema:
+
+ package My::Types {
+     use Type::Library -base;
+     use Type::FromSah qw( sah2type );
+
+     __PACKAGE__->add_type(
+         sah2type('$sch_name*', name=>'DateDowNumsEnOrId')
+     );
+ }
+
+ use My::Types qw(DateDowNumsEnOrId);
+ DateDowNumsEnOrId->assert_valid($data);
+
 =head1 DESCRIPTION
 
 Like the L<date::dow_nums|Sah::Schema::date::dow_nums> except the elements are
@@ -185,14 +200,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Date-ID>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Date-ID>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Sah::Schema::date::dow_nums>
@@ -205,11 +212,37 @@ L<Sah::Schema::date::dow_num::en_or_id>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2020, 2019 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Date-ID>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
